# frozen_string_literal: true

require "models/arunit2_model"

class OtherDog < ARUnit2Model
  self.table_name = "dogs"
end
